@@ -2,7 +2,7 @@
 # BSD 2-Clause License
 #
 # Apprise - Push Notification Library.
-# Copyright (c) 2024, Chris Caron <lead2gold@gmail.com>
+# Copyright (c) 2025, Chris Caron <lead2gold@gmail.com>
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -74,8 +74,7 @@ from .base import NotifyBase
 from ..locale import gettext_lazy as _
 from ..url import PrivacyMode
 from ..common import NotifyType
-from ..utils import is_call_sign
-from ..utils import parse_call_sign
+from ..utils.parse import is_call_sign, parse_call_sign
 from .. import __version__
 import re
 
